package com.sf.system.deployment.service;

import com.sf.system.deployment.domain.DeploymentApplyEnvironment;

import java.util.List;

/**
 * 环境维护Service接口
 * 
 * @author ztzh
 * @date 2024-04-19
 */
public interface IDeploymentApplyEnvironmentService 
{
    /**
     * 查询环境维护
     * 
     * @param id 环境维护主键
     * @return 环境维护
     */
    public DeploymentApplyEnvironment selectDeploymentApplyEnvironmentById(Long id);

    /**
     * 查询环境维护列表
     * 
     * @param deploymentApplyEnvironment 环境维护
     * @return 环境维护集合
     */
    public List<DeploymentApplyEnvironment> selectDeploymentApplyEnvironmentList(DeploymentApplyEnvironment deploymentApplyEnvironment);

    /**
     * 新增环境维护
     * 
     * @param deploymentApplyEnvironment 环境维护
     * @return 结果
     */
    public int insertDeploymentApplyEnvironment(DeploymentApplyEnvironment deploymentApplyEnvironment);

    /**
     * 修改环境维护
     * 
     * @param deploymentApplyEnvironment 环境维护
     * @return 结果
     */
    public int updateDeploymentApplyEnvironment(DeploymentApplyEnvironment deploymentApplyEnvironment);

    /**
     * 批量删除环境维护
     * 
     * @param ids 需要删除的环境维护主键集合
     * @return 结果
     */
    public int deleteDeploymentApplyEnvironmentByIds(Long[] ids);

    /**
     * 删除环境维护信息
     * 
     * @param id 环境维护主键
     * @return 结果
     */
    public int deleteDeploymentApplyEnvironmentById(Long id);
}
